==> jc-1.4.0.tar.gz: java/awt/dnd/DropTarget__24DropTargetAutoScroller.h <==
// public class java.awt.dnd.DropTarget$DropTargetAutoScroller

// class file dependencies
// @dep_class 6648d428ca3968c1 java_awt_dnd_DropTarget__24DropTargetAutoScroller
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_dnd_DropTarget__24DropTargetAutoScroller_H_
#define _JC_java_awt_dnd_DropTarget__24DropTargetAutoScroller_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Point$object;
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$sub_refs	_jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$sub_refs;
typedef struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$sub_nonrefs	_jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$sub_nonrefs;
typedef struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$refs	_jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$refs;
typedef struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$nonrefs	_jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$nonrefs;
typedef struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$object	_jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$object;

typedef const struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$vmethods	_jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$vmethods;
typedef const struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$vtable	_jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$vtable;
typedef const struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$vtype	_jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$vtype;

// Constructors
extern void _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$method$_init$649998b4f29d0ffc(_jc_env *, struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Point$object *);

// Virtual methods
extern void _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$object *, struct _jc_java_awt_event_ActionEvent$object *);
extern void _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$method$stop$a0f6e77c591d5cb1(_jc_env *, struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$object *);
extern void _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$method$updateLocation$7df3141adf8fdea5(_jc_env *, struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$object *, struct _jc_java_awt_Point$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$method_info$actionPerformed$9046a9754e643ffd;
extern _jc_method _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$method_info$stop$a0f6e77c591d5cb1;
extern _jc_method _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$method_info$updateLocation$7df3141adf8fdea5;

// Virtual methods structure
struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$object *, struct _jc_java_awt_event_ActionEvent$object *);
	void	(*stop$a0f6e77c591d5cb1)(_jc_env *, struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$object *);
	void	(*updateLocation$7df3141adf8fdea5)(_jc_env *, struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$object *, struct _jc_java_awt_Point$object *);
};

// Vtable
struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$vmethods	java_awt_dnd_DropTarget__24DropTargetAutoScroller;
};

// Vtype
struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$vtype {
	_jc_type			type;
	_jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$sub_refs {
	struct _jc_java_awt_Component$object	*component;
	struct _jc_java_awt_Point$object	*point;
};

// Reference instance fields (object)
struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$refs {
    _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$sub_refs	java_awt_dnd_DropTarget__24DropTargetAutoScroller;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$sub_nonrefs	java_awt_dnd_DropTarget__24DropTargetAutoScroller;
};

// Object instance structure
struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$object {
	_jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$vtype	*vtype;
	_jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$vtype _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_dnd_DropTarget__24DropTargetAutoScroller, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$class_object;

#endif	/* _JC_java_awt_dnd_DropTarget__24DropTargetAutoScroller_H_ */

==> jc-1.4.6.tar.gz: java/awt/dnd/DropTarget__24DropTargetAutoScroller.h <==
// public class java.awt.dnd.DropTarget$DropTargetAutoScroller

// class file dependencies
// @dep_class 6648d428ca3968c1 java_awt_dnd_DropTarget__24DropTargetAutoScroller
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_dnd_DropTarget__24DropTargetAutoScroller_H_
#define _JC_java_awt_dnd_DropTarget__24DropTargetAutoScroller_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Point$object;
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$sub_refs	_jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$sub_refs;
typedef struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$sub_nonrefs	_jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$sub_nonrefs;
typedef struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$refs	_jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$refs;
typedef struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$nonrefs	_jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$nonrefs;
typedef struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$object	_jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$object;

typedef const struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$vmethods	_jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$vmethods;
typedef const struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$vtable	_jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$vtable;
typedef const struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$vtype	_jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$vtype;

// Constructors
extern void _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$method$_init$649998b4f29d0ffc(_jc_env *, struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Point$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$method$stop$a0f6e77c591d5cb1(_jc_env *, struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$method$updateLocation$7df3141adf8fdea5(_jc_env *, struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$object *, struct _jc_java_awt_Point$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$method_info$actionPerformed$9046a9754e643ffd;
extern _jc_method _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$method_info$stop$a0f6e77c591d5cb1;
extern _jc_method _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$method_info$updateLocation$7df3141adf8fdea5;

// Virtual methods structure
struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
	void	(*stop$a0f6e77c591d5cb1)(_jc_env *, struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$object *) _JC_JCNI_ATTR;
	void	(*updateLocation$7df3141adf8fdea5)(_jc_env *, struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$object *, struct _jc_java_awt_Point$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$vmethods	java_awt_dnd_DropTarget__24DropTargetAutoScroller;
};

// Vtype
struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$vtype {
	_jc_type			type;
	_jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$sub_refs {
	struct _jc_java_awt_Component$object	*component;
	struct _jc_java_awt_Point$object	*point;
};

// Reference instance fields (object)
struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$refs {
    _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$sub_refs	java_awt_dnd_DropTarget__24DropTargetAutoScroller;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$sub_nonrefs	java_awt_dnd_DropTarget__24DropTargetAutoScroller;
};

// Object instance structure
struct _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$object {
	_jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$vtype	*vtype;
	_jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$vtype _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_dnd_DropTarget__24DropTargetAutoScroller, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_dnd_DropTarget__24DropTargetAutoScroller$class_object;

#endif	/* _JC_java_awt_dnd_DropTarget__24DropTargetAutoScroller_H_ */
